Isomer System overview
======================

Architecture
------------

The system consists of two parts:
1. A backend written in Python. It handles communications, data handling and other general services provided by independent modules.
2. To communicate with users, a HTML5 based Frontend is deployed to most modern web browser capable clients.

Meshed Operation
----------------

The cloud/server-less mesh operation enables local independence and adaptability regarding
network environments.

No platform specifics
---------------------

It also eliminates the need to write platform specific applications (e.g. native Android
or other mobile platform applications)

